Placeholder for platform-specific init scripts. Modify them to add cleanup
steps you want to run after completion of a task. Examples include app
specific artifacts cleanup from non-temp directories.
